glendam/protocol/security

This module is generated from the Chrome DevTools Protocol schema.

Do not edit this file manually. Generator: dev/codegen/generate_bindings.gleam Regenerate with:

gleam run -m codegen/generate_bindings

Protocol version: 1.3

Security Domain

Security

📖 View this domain on the DevTools Protocol API Docs

Types

The action to take when a certificate error occurs. continue will continue processing the request and cancel will cancel the request.

pub type CertificateErrorAction {
  CertificateErrorActionContinue
  CertificateErrorActionCancel
}

Constructors

  • CertificateErrorActionContinue

    Represents the continue protocol value.

  • CertificateErrorActionCancel

    Represents the cancel protocol value.

An internal certificate ID value.

pub type CertificateId {
  CertificateId(Int)
}

Constructors

  • CertificateId(Int)

    Represents the CertificateId protocol value.

A description of mixed content (HTTP resources on HTTPS pages), as defined by https://www.w3.org/TR/mixed-content/#categories

pub type MixedContentType {
  MixedContentTypeBlockable
  MixedContentTypeOptionallyBlockable
  MixedContentTypeNone
}

Constructors

  • MixedContentTypeBlockable

    Represents the blockable protocol value.

  • MixedContentTypeOptionallyBlockable

    Represents the optionally-blockable protocol value.

  • MixedContentTypeNone

    Represents the none protocol value.

The security level of a page or resource.

pub type SecurityState {
  SecurityStateUnknown
  SecurityStateNeutral
  SecurityStateInsecure
  SecurityStateSecure
  SecurityStateInfo
  SecurityStateInsecureBroken
}

Constructors

  • SecurityStateUnknown

    Represents the unknown protocol value.

  • SecurityStateNeutral

    Represents the neutral protocol value.

  • SecurityStateInsecure

    Represents the insecure protocol value.

  • SecurityStateSecure

    Represents the secure protocol value.

  • SecurityStateInfo

    Represents the info protocol value.

  • SecurityStateInsecureBroken

    Represents the insecure-broken protocol value.

An explanation of an factor contributing to the security state.

pub type SecurityStateExplanation {
  SecurityStateExplanation(
    security_state: SecurityState,
    title: String,
    summary: String,
    description: String,
    mixed_content_type: MixedContentType,
    certificate: List(String),
    recommendations: option.Option(List(String)),
  )
}

Constructors

  • SecurityStateExplanation(
      security_state: SecurityState,
      title: String,
      summary: String,
      description: String,
      mixed_content_type: MixedContentType,
      certificate: List(String),
      recommendations: option.Option(List(String)),
    )

    Represents the SecurityStateExplanation protocol value.

    Arguments

    security_state

    Security state representing the severity of the factor being explained.

    title

    Title describing the type of factor.

    summary

    Short phrase describing the type of factor.

    description

    Full text explanation of the factor.

    mixed_content_type

    The type of mixed content described by the explanation.

    certificate

    Page certificate.

    recommendations

    Recommendations to fix any issues.

Values

pub fn disable(
  callback callback__: fn(String, option.Option(json.Json)) -> Result(
    dynamic.Dynamic,
    chrome.RequestError,
  ),
) -> Result(dynamic.Dynamic, chrome.RequestError)

Disables tracking security state changes.

pub fn enable(
  callback callback__: fn(String, option.Option(json.Json)) -> Result(
    dynamic.Dynamic,
    chrome.RequestError,
  ),
) -> Result(dynamic.Dynamic, chrome.RequestError)

Enables tracking security state changes.

pub fn set_ignore_certificate_errors(
  callback callback__: fn(String, option.Option(json.Json)) -> Result(
    dynamic.Dynamic,
    chrome.RequestError,
  ),
  ignore ignore: protocol_support.BooleanSetting,
) -> Result(dynamic.Dynamic, chrome.RequestError)

Enable/disable whether all certificate errors should be ignored.

Parameters:

  • ignore : If true, all certificate errors will be ignored.

Returns:

Search Document